# -*- coding: utf-8 -*-
# Generated by the windmill services transformer
from windmill.authoring import WindmillTestClient

"""These tests must be loaded by Windmill.
Command example: $ windmill shell firefox http://localhost:8080 field_creation.py
"""

def test_login():
    """Some parameters must be modified (user, password, Plone URL).
    """
    client = WindmillTestClient(__name__)

    client.click(link=u'View your Plone site.')
    client.waits.forPageLoad(timeout=u'20000')
    client.waits.forElement(timeout=u'8000', id=u'__ac_name')
    client.type(text=u'admin', id=u'__ac_name') # To replace with the corrects username and password
    client.type(text=u'password', id=u'__ac_password')
    client.click(name=u'submit')
    client.waits.forPageLoad(timeout=u'20000')

def test_createDB():
    client = WindmillTestClient(__name__)

    client.click(link=u'Home')
    client.waits.forPageLoad(timeout=u'20000')
    client.waits.forElement(xpath=u"//dl[@id='plone-contentmenu-factories']/dt/a/span[1]", timeout=u'8000')
    client.click(xpath=u"//dl[@id='plone-contentmenu-factories']/dt/a/span[1]")
    client.click(xpath=u"//a[@id='plominodatabase']/span")
    client.waits.forPageLoad(timeout=u'20000')
    client.type(text=u'testdb', id=u'title')
    client.click(name=u'form.button.save')
    client.waits.forPageLoad(timeout=u'20000')

def test_createForm():
    client = WindmillTestClient(__name__)

    client.click(xpath=u"//dl[@id='plone-contentmenu-factories']/dt/a/span[1]")
    client.click(xpath=u"//a[@id='plominoform']/span")
    client.waits.forPageLoad(timeout=u'20000')
    client.waits.forElement(timeout=u'8000', id=u'id')
    client.type(text=u'testform', id=u'id')
    client.type(text=u'testform', id=u'title')
    client.click(name=u'form.button.save')
    client.waits.forPageLoad(timeout=u'20000')

def test_createField():
    client = WindmillTestClient(__name__)

    client.click(link=u'Edit')
    client.waits.forPageLoad(timeout=u'20000')
    client.waits.forElement(xpath=u"//body[@id='content']", timeout=u'8000')
    client.click(xpath=u"//body[@id='content']")
    client.click(id=u'FormLayout_plominofield')
    client.waits.forElement(timeout=u'5000', id=u'plominoFieldId')
    client.type(text=u'field1', id=u'plominoFieldId')
    client.click(id=u'insert')
    client.click(name=u'form.button.save')
    client.waits.forPageLoad(timeout=u'20000')



class PlominoField(object):
    """
    """
    
    def __init__(self, context, request):
        """Initialize adapter."""
        self.context = context
        self.request = request
        
    def __call__(self):
        """
        """
        return self

    def setFieldProperties(self):
        """Set field properties to their new values. 
        """
        fieldid = self.request.get("fieldid", None)
        fieldtype = self.request.get("fieldtype", None)
        fieldmode = self.request.get("fieldmode", None)
        fieldformula = self.request.get("fieldformula", None)
        
        # self.context is the current field
        if fieldid and fieldid == self.context.id:
            if fieldtype:
                self.context.setFieldType(fieldtype)
            if fieldmode:
                self.context.setFieldMode(fieldmode)
            if fieldformula:
                self.context.setFormula(fieldformula)
            self.context.aq_parent.aq_parent.at_post_edit_script()
        
        self.request.RESPONSE.redirect(self.context.portal_url() + "/plomino_plugins/plominofield/plominofield_submit.htm")



from Products.CMFPlomino.config import FIELD_TYPES#, FIELD_MODES


class PlominoForm(object):
    """
    """
    
    def __init__(self, context, request):
        """Initialize adapter."""
        self.context = context
        self.request = request
        
    def __call__(self):
        """
        """
        return self
     
    def getFieldTypes(self):
        """Return a list of possible types for a field.
        """
        return [(pair[0], pair[1][0]) for pair in FIELD_TYPES.items()]
    
    def getFieldModes(self):
        """Return a list of possible modes for a field.
        """
        # replace with "return FIELD_MODES" when available (see import)
        return [["EDITABLE", "Editable"], ["COMPUTED", "Computed"], ["CREATION", "Computed on creation"], ["DISPLAY", "Computed for display"]]
        
    def addField(self):
        """ Add a field to the form. 
        """
        fieldid = self.request.get("fieldid", None)
        fieldtype = self.request.get("fieldtype", "TEXT")
        fieldmode = self.request.get("fieldmode", "EDITABLE")
        fieldformula = self.request.get("fieldformula", "")
        
        # self.context is the current form
        if fieldid and fieldid not in (field.id for field in self.context.getFields()):
            self.context.invokeFactory('PlominoField', id=fieldid, Title=fieldid, FieldType=fieldtype, FieldMode=fieldmode)
            field = self.context.aq_parent.aq_parent.getFormField(fieldid)
            field.setFormula(fieldformula)
            field.at_post_create_script()
        
        self.request.RESPONSE.redirect(self.context.portal_url() + "/plomino_plugins/plominofield/plominofield_submit.htm")
